@@ -16,7 +16,7 @@ module Rabl
 
       @_view_path     = options[:view_path]
       @_context_scope = options[:scope]
-      
+
       @_cache_read_on_render = true
     end
 
@@ -94,7 +94,7 @@ module Rabl
     end
 
     def to_dumpable(options = {})
-      options = { 
+      options = {
         :child_root => Rabl.configuration.include_child_root
       }.merge(options)
 
@@ -132,7 +132,7 @@ module Rabl
     # to_xml(:root => true)
     def to_xml(options = {})
       options = {
-        :root       => (include_root = Rabl.configuration.include_xml_root), 
+        :root       => (include_root = Rabl.configuration.include_xml_root),
         :child_root => include_root && Rabl.configuration.include_child_root
       }.merge(options)
 
@@ -163,9 +163,11 @@ module Rabl
     def object(template_data)
       current_data  = (@_locals[:object].nil? || template_data == false) ? template_data : @_locals[:object]
       @_data_object = data_object(current_data)
-      @_data_name   = data_name(template_data.is_a?(Hash) && !current_data.is_a?(Hash) ? template_data : current_data)
+      @_root_name_data = template_data.is_a?(Hash) && !current_data.is_a?(Hash) ? template_data : current_data
+      @_root_name_data = @_root_name_data.values.first if @_root_name_data.is_a?(Hash)
 
-      if @_data_name == false
+      # If we turn this around, `@_root_name_date ==` may trigger data to be loaded unnecessarily.
+      if false == @_root_name_data
         @_object_root_name = false
         @_collection_name = false
       end
@@ -185,7 +187,7 @@ module Rabl
       return @_data_name if defined?(@_data_name)
 
       @_data_name = @_options[:object_root_name] || begin
-        data = @_locals[:object].nil? ? root_object : @_locals[:object]
+        data = defined?(@_root_name_data) ? @_root_name_data : (@_locals[:object].nil? ? root_object : @_locals[:object])
         data_name(data)
       end
     end
@@ -201,7 +203,7 @@ module Rabl
 
       @_object_root_name = options[:object_root] if options.has_key?(:object_root)
 
-      object(Array(data_object(data)))
+      object(data_object(data) || [])
     end
 
     # Sets the cache key to be used by ActiveSupport::Cache.expand_cache_key
@@ -211,7 +213,7 @@ module Rabl
     # cache                  # uses the current item within a collection
     # cache 'user', expires_in: 1.hour
     # options is passed through to the cache store
-    def cache(key = nil, options = nil)
+    def cache(key = nil, options = {})
       key ||= root_object # if called but missing, use object
       @_cache_key     = key
       @_cache_options = options
@@ -226,12 +228,12 @@ module Rabl
         attr_aliases  = args.first.except(:if, :unless)
         conditions    = args.first.slice(:if, :unless)
 
-        attr_aliases.each do |key, as| 
+        attr_aliases.each do |key, as|
           attribute(key, conditions.merge(:as => as))
         end
       else # array of attributes i.e :foo, :bar, :baz
         options = args.extract_options!
-        args.each do |name| 
+        args.each do |name|
           @_settings[:attributes] << { :name => name, :options => options }
         end
       end
@@ -387,18 +389,18 @@ module Rabl
       end
 
       def digestor_available?
-        defined?(Rails) && Rails.version =~ /^[4]/
+        defined?(Rails) && Rails.version =~ /^[45]/
       end
 
       def set_instance_variables!(context_scope, locals)
         @_context_scope = context_scope
-        @_locals        = locals
+        @_locals        = locals || {}
 
         copy_instance_variables_from(context_scope, [:@assigns, :@helpers])
 
         @_options[:format] ||= request_format
 
-        set_locals(locals)
+        set_locals(@_locals)
       end
 
       def set_locals(locals)
@@ -408,7 +410,7 @@ module Rabl
 
       def eval_source(locals, &block)
         # Note: locals and block may be used by the eval'ed source
-        
+
         return unless @_source.present?
 
         if @_options[:source_location]
