@@ -35,7 +35,8 @@ module Rabl
       data = data_object(data_token)
 
       if is_collection?(data) # data is a collection
-        object_name = data.table_name if data.respond_to?(:table_name)
+        object_name = collection_root_name if collection_root_name
+        object_name ||= data.table_name if data.respond_to?(:table_name)
 
         if object_name.nil? && data.respond_to?(:first)
           first = data.first
@@ -137,12 +138,12 @@ module Rabl
 
     # Fetches a key from the cache and stores rabl template result otherwise
     # fetch_from_cache('some_key') { ...rabl template result... }
-    def fetch_result_from_cache(cache_key, cache_options = nil, &block)
+    def fetch_result_from_cache(cache_key, cache_options = {}, &block)
       expanded_cache_key = ActiveSupport::Cache.expand_cache_key(cache_key, :rabl)
       Rabl.configuration.cache_engine.fetch(expanded_cache_key, cache_options, &block)
     end
 
-    def write_result_to_cache(cache_key, cache_options = nil, &block)
+    def write_result_to_cache(cache_key, cache_options = {}, &block)
       expanded_cache_key = ActiveSupport::Cache.expand_cache_key(cache_key, :rabl)
       result = yield
       Rabl.configuration.cache_engine.write(expanded_cache_key, result, cache_options)
